<?php
/**
 * @file
 */

namespace Drupal\zwc\Controller;

use Drupal\Core\Controller\ControllerBase;
//use Drupal\Core\Cache\CacheableJsonResponse
use Drupal\Core\Cache\CacheableMetadata;
use \Drupal\zwc\Entity\ZWCCore;

use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\Yaml\Yaml;

/**
 * Class ZWCController
 *
 * Provides the route controller for zwc.
 */
class ZWCController extends ControllerBase
{
  /**
   * @param $uuid
   * @return JsonResponse
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function get_settings_json($uuid) {
    $resp = $this->get_settings_data($uuid);
    if ($resp) {
      // Add the zwc_core cache tag so the endpoint results will update when nodes are
      // updated.
      $cache_metadata = new CacheableMetadata();
      $cache_metadata->setCacheTags(['zwc_core']);

      // Create the JSON response object and add the cache metadata.
      //$response = new CacheableJsonResponse($response_array);
      //$response->addCacheableDependency($cache_metadata);
      $response = new JsonResponse($resp);

      return $response;
    }
    else {
      $response = new JsonResponse([]);
      return $response;
    }
  }

  /**
   * @param $uuid
   * @return array|bool
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function get_settings_data($uuid)
  {
    // Check the uuid
    $check = FALSE;
    if (is_string($uuid) && (preg_match('/^[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/', $uuid) === 1)) {
      $check = TRUE;
    }
    if ($check) {
      $n = \Drupal::entityTypeManager()->getStorage('zwc_core')->loadByProperties(['uuid' => $uuid]);
      $id = array_keys($n)[0];
      if ($id) {
        $core = ZWCCore::load($id);

        // First see if we have a custom field
        if ($core->hasField('field_settings_yaml') && !empty($core->get('field_settings_yaml')->getValue())) {
          $yaml = Yaml::parse($core->get('field_settings_yaml')->getValue()[0]['value']);
          return $yaml;
        }
        else {
          // TODO Implement plugins
          return FALSE;
        }
      }
      else {
        return FALSE;
      }
    }
    else {
      return FALSE;
    }
  }

  /**
   * @param $zwc_core
   * @param $entity_type
   * @param $entity_id
   * @return RedirectResponse
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function remove_plugin($zwc_core, $entity_type, $entity_id) {
    $core = \Drupal::entityTypeManager()->getStorage('zwc_core')->load($zwc_core);
    $field_current = $core->get('field_zwc_enabled_plugins')->getValue();
    $field_new = array();
    foreach ($field_current as $fc) {
      if ($fc['target_id'] !== $entity_id || $fc['target_type'] !== $entity_type) {
        $field_new[] = $fc;
      }
    }
    $core->field_zwc_enabled_plugins->setValue($field_new);
    $core->save();

    drupal_set_message('Plugin was removed');

    $response = new RedirectResponse($_SERVER['HTTP_REFERER']);
    return $response;
  }
}