<?php

namespace Drupal\zwc\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining ZWCCore entities.
 *
 * @ingroup zwc
 */
interface ZWCCoreInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the ZWCCore name.
   *
   * @return string
   *   Name of the ZWCCore.
   */
  public function getName();

  /**
   * Sets the ZWCCore name.
   *
   * @param string $name
   *   The ZWCCore name.
   *
   * @return \Drupal\zwc\Entity\ZWCCoreInterface
   *   The called ZWCCore entity.
   */
  public function setName($name);

  /**
   * Gets the ZWCCore creation timestamp.
   *
   * @return int
   *   Creation timestamp of the ZWCCore.
   */
  public function getCreatedTime();

  /**
   * Sets the ZWCCore creation timestamp.
   *
   * @param int $timestamp
   *   The ZWCCore creation timestamp.
   *
   * @return \Drupal\zwc\Entity\ZWCCoreInterface
   *   The called ZWCCore entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the ZWCCore published status indicator.
   *
   * Unpublished ZWCCore are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the ZWCCore is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a ZWCCore.
   *
   * @param bool $published
   *   TRUE to set this ZWCCore to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\zwc\Entity\ZWCCoreInterface
   *   The called ZWCCore entity.
   */
  public function setPublished($published);

}
