<?php

namespace Drupal\zwc;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the ZWCCore entity.
 *
 * @see \Drupal\zwc\Entity\ZWCCore.
 */
class ZWCCoreAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\zwc\Entity\ZWCCoreInterface $entity */
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished zwc_core entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'view published zwc_core entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit zwc_core entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete zwc_core entities');
    }

    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add zwc_core entities');
  }

}
